def say_hello(name):
    github_pat = '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'
    aws_access_key = 'AKIAYZZGSY75LDOLKSUF'
    aws_secret_key = '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'
    return f"Hello, {name}!"
