from setuptools import setup, find_packages

setup(
    name='pythongardenerpersonalpkg',
    version='0.3',
    packages=find_packages(),
    description='A simple example package',
    author='Your Name',
    author_email='your.email@example.com',
    url='https://github.com/yourusername/pythongardenerpersonalpkg',  # Optional
    install_requires=[],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
